@@ -1,6 +1,6 @@
 complexity.LASSO <- function(response, x, full.data, ...){
-   require(penalized)
-   prof <- profL1(response=response, penalized=x, trace=FALSE, ...)
+   #requireNamespace(penalized)
+   prof <- penalized::profL1(response=response, penalized=x, trace=FALSE, ...)
    lambda <- prof$lambda[which.max(prof$cvl)]
    lambda
 }
\ No newline at end of file
